@@ -1,14 +1,14 @@
 use core::panic;
+use std::fs;
 use std::path::{Path, PathBuf};
 
 use env_logger as logger;
-use nom::error::ErrorKind;
 use rustdoc_types::Crate;
 use rustyline::error::ReadlineError;
 use rustyline::Editor;
 use structopt::StructOpt;
 
-use roogle_engine::{exec::QueryExecutor, parse::parse_query};
+use roogle_engine::{exec::QueryExecutor, parse::parse_query, types::Crates};
 
 #[derive(StructOpt, Debug)]
 struct Config {
@@ -27,10 +27,15 @@ fn main() {
     logger::init();
 
     let cfg = Config::from_args();
-    let krate = serde_json::from_str::<Crate>(&read_json(cfg.index))
-        .expect("msfailed in deserializing crate");
 
-    let qe = QueryExecutor::new(krate);
+    let krates: Vec<Crate> = fs::read_dir(cfg.index)
+        .unwrap()
+        .map(Result::unwrap)
+        .map(|entry| serde_json::from_str(&read_json(entry.path())).unwrap())
+        .collect();
+    let krates = Crates::from(krates);
+
+    let qe = QueryExecutor::new(krates);
 
     let mut rl = Editor::<()>::new();
     loop {
@@ -39,15 +44,13 @@ fn main() {
             Ok(line) => {
                 rl.add_history_entry(line.as_str());
 
-                let query = parse_query::<(&str, ErrorKind)>(&line)
-                    .expect("failed in parsing query")
-                    .1;
+                let query = parse_query(&line).expect("failed in parsing query").1;
                 let items = qe.exec(query);
                 for item in items.iter().take(3) {
-                    println!("{:?}", item);
+                    println!("{:?}", item.name);
                 }
             }
-            Err(ReadlineError::Interrupted) => break,
+            Err(ReadlineError::Interrupted) | Err(ReadlineError::Eof) => break,
             _ => panic!("exitted repl"),
         }
     }
